Crate ferrox_actions

Crate ferrox_actions 

Re-exports

pub use birdeye::BirdeyeActionGroup;
pub use coingecko::CoinGeckoActionGroup;
pub use dexscreener::DexScreenerActionGroup;
pub use gmgn::GmgnActionGroup;

Modules

birdeye
coingecko
dexscreener
gmgn

Structs

ActionBuilder
A builder to create actions from async functions with typed parameters F: The handler function type P: Input parameters for the handler S: State type Q: Output type from handler and input type for confirm handler CF: Confirm handler function type (defaults to EmptyConfirmHandler)
ActionDefinition
ActionParameter
EmptyParams
FunctionAction

Traits

ActionGroup
Represents a group of related actions

Type Aliases

AgentState
ConfirmHandler