pub struct ActionBuilder<F, P, V, S, Q = String, CF = fn(Q, V, AgentState<S>) -> Pin<Box<dyn Future<Output = Result<String, String>> + Send + Sync>>> { /* private fields */ }Expand description
A builder to create actions from async functions with typed parameters F: The handler function type P: Input parameters for the handler S: State type Q: Output type from handler and input type for confirm handler CF: Confirm handler function type (defaults to EmptyConfirmHandler)
Implementations
Sourceimpl<F, CF, P, Q, S, V, Fut, CFut> ActionBuilder<F, P, V, S, Q, CF>where
F: Fn(P, V, AgentState<S>) -> Fut + Send + Sync + Clone + 'static,
Fut: Future<Output = Result<Q, String>> + Send + Sync + 'static,
P: DeserializeOwned + Send + 'static,
CF: Fn(Q, V, AgentState<S>) -> CFut + Send + Sync + Clone + 'static,
CFut: Future<Output = Result<String, String>> + Send + Sync + 'static,
Q: Serialize + DeserializeOwned + Send + 'static,
S: Send + Sync + Clone + 'static,
V: Serialize + DeserializeOwned + Send + 'static,
impl<F, CF, P, Q, S, V, Fut, CFut> ActionBuilder<F, P, V, S, Q, CF>where
F: Fn(P, V, AgentState<S>) -> Fut + Send + Sync + Clone + 'static,
Fut: Future<Output = Result<Q, String>> + Send + Sync + 'static,
P: DeserializeOwned + Send + 'static,
CF: Fn(Q, V, AgentState<S>) -> CFut + Send + Sync + Clone + 'static,
CFut: Future<Output = Result<String, String>> + Send + Sync + 'static,
Q: Serialize + DeserializeOwned + Send + 'static,
S: Send + Sync + Clone + 'static,
V: Serialize + DeserializeOwned + Send + 'static,
pub fn new( name: impl Into<String>, handler: F, confirm_handler: Option<CF>, ) -> Self
pub fn description(self, description: impl Into<String>) -> Self
pub fn parameter( self, name: impl Into<String>, description: impl Into<String>, param_type: impl Into<String>, required: bool, ) -> Self
pub fn build(self) -> FunctionAction<S>